@@ -5,7 +5,7 @@ BEGIN {
   use Exporter;
   use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
 
-  $VERSION = '0.158';
+  $VERSION = '0.160';
   @ISA = qw(Exporter);
 
   @EXPORT_OK = qw(
@@ -32,7 +32,7 @@ my $internal_ls_color = '
 :*.flv=38;5;131:*.spl=38;5;44:*.sug=38;5;44:*.1=38;5;196;1:*.eps=38;5;192:
 *.xpm=38;5;32:*.gif=38;5;35:*.info=38;5;101:*.lua=38;5;34;1:*.t=38;5;028;1:
 *.textile=38;5;106:ln=target:*.hs=38;5;159:*.ini=38;5;122:*.part=38;5;240:
-*.pid=38;5;160:*.pod=38;5;106:*.vim=1:*.git=38;5;197:*.urlview=38;5;85:
+*.pid=38;5;160:*.pod=38;5;178:*.vim=1:*.git=38;5;197:*.urlview=38;5;85:
 *.dump=38;5;119:*.conf=1:*.md=38;5;184:*.markdown=38;5;184:*.mkd=38;5;184:
 *.h=38;5;81:*.rb=38;5;192:*.c=38;5;110:*.diff=42;38:*.yml=38;5;208:
 *.PL=38;5;160:*.csv=38;5;78:tw=38;5;208;1:*.chm=38;5;144:*.bin=38;5;249:
@@ -85,8 +85,9 @@ ln=target:pi=38;5;126:ow=38;5;208;1:di=38;5;30:*.pm=38;5;197;1:
 *.example=38;5;225;1:*.un~=38;5;240:*.out=38;5;46;1:*.tdy=38;5;214:
 *.mfasl=38;5;73:*.rdf=38;5;144:*.sqlite=38;5;60:*.jsm=38;5;142;1:
 *.jad=38;5;142:*.jar=38;5;142:*.jhtm=38;5;142:*.jsp=38;5;142:*.ru=38;5;142:
-*.torrent=38;5;58:*.fcm=38;5;41:*.fm2=38;5;35:*.htm=38;5;56:*.html=38;5;56:
-*.go=38;5;36;1:*.err=38;5;160;1:*.error=38;5;160;1:*.old=38;5;244';
+*.torrent=38;5;58:*.fcm=38;5;41:*.fm2=38;5;35:*.htm=38;5;125;1:
+*.html=38;5;125;1:*.go=38;5;36;1:*.err=38;5;160;1:*.error=38;5;160;1:
+*.old=38;5;244:*.signature=38;5;206:*.bak=38;5;41;1';
 
 $internal_ls_color =~ s/\n//g;
 
